@@ -67,30 +67,6 @@ def async_options(function: Callable) -> Callable:
     return function
 
 
-def show_all_issues_option(function: Callable) -> Callable:
-    """Used for showing all issues (warnings, future-errors, and errors) instead of just errors"""
-    return click.option(
-        "--show-all", is_flag=True, default=False, help="If specified, prints warnings and future-errors"
-    )(function)
-
-
-def verbose_issues_option(function: Callable) -> Callable:
-    """Used for showing extra details issues might have that aren't shown by default"""
-    return click.option(
-        "--verbose-issues", is_flag=True, default=False, help="If specified, prints any extra details issues might have"
-    )(function)
-
-
-def dw_timeout_option(function: Callable) -> Callable:
-    """Used for timing out async dw validation results polling"""
-    return click.option(
-        "-t",
-        "--timeout",
-        type=int,
-        help="Sets the timeout in seconds to wait for individual data warehouse validations to finish. Defaults to None, meaning no timeout",
-    )(function)
-
-
 def config_validation_options(function: Callable) -> Callable:
     """Common options when validating or committing configs"""
     function = click.option(
@@ -100,17 +76,6 @@ def config_validation_options(function: Callable) -> Callable:
         default=os.getcwd(),
         help="Path to directory containing Transform yaml models",
     )(function)
-
-    function = click.option(
-        "--skip-dw",
-        is_flag=True,
-        default=False,
-        help="If specified, skips the data warehouse validations",
-    )(function)
-
-    function = show_all_issues_option(function)
-    function = verbose_issues_option(function)
-    function = dw_timeout_option(function)
     return function
 
 
