@@ -15,32 +15,27 @@ from datetime import datetime
 from packaging.version import parse
 
 from log_symbols import LogSymbols
+from termcolor import colored
 from update_checker import UpdateChecker
 
 from ..pretty_pandas import prettify
 
-from ..interfaces import AsyncDWValidationType
+from ..interfaces import DWValidationType
 
 from .cli_context import CLIContext
 from .cli_utils import (
-    dw_timeout_option,
     metrics_and_dimensions_options,
     query_options,
     config_validation_options,
     async_options,
     no_active_mql_servers,
-    show_all_issues_option,
     validate_query_args,
     enable_debug_log_file,
     get_query_logs_url_for_id,
     query_observability_options,
     exception_handler,
     start_end_time_options,
-    verbose_issues_option,
 )
-from metricflow.cli.main import _print_issues
-from metricflow.model.parsing.config_linter import ConfigLinter
-from metricflow.model.validations.validator_helpers import ModelValidationResults
 from ..models import (
     CacheMode,
     PercentChange,
@@ -896,157 +891,72 @@ def list_queries(
             click.echo(f"• query_id={q.id}, status={q.status.value}")
 
 
-def _run_dw_validations(
-    config: CLIContext,
-    dw_validation_type: AsyncDWValidationType,
-    model_id: Optional[int] = None,
-    timeout: Optional[int] = None,
-) -> List[str]:
+def _run_dw_validations(config: CLIContext, type: DWValidationType, model_id: Optional[int] = None) -> List[str]:
     """Helper handles the calling of data warehouse issue generating functions"""
 
     spinner = Halo(
-        text=f"Validating {dw_validation_type.name} elements on model {model_id} against data warehouse...",
-        spinner="dots",
+        text=f"Validating {type.name.lower()} elements on model {model_id} against data warehouse...", spinner="dots"
     )
     spinner.start()
-    job_id = config.mql.create_data_warehouse_validations_job(dw_validation_type=dw_validation_type)
-    results = config.mql.get_data_warehouse_validations_job_result(query_id=job_id, timeout=timeout)
-    if results.has_blocking_issues:
-        spinner.fail(
-            f"Breaking issues found when validating {dw_validation_type.name} elements against data warehouse ({results.summary()})"
+    issues = config.mql.get_data_warehouse_issues(type=type, model_key_id=model_id)
+    if issues is not None and len(issues) == 0:
+        spinner.succeed(
+            f"🎉 Finished validating {type.name.lower()} elements on model {model_id} against data warehouse, no issues found"
         )
     else:
-        spinner.succeed(
-            f"🎉 Successfully validated {dw_validation_type.name} elements against data warehouse ({results.summary()})"
+        spinner.fail(
+            f"😬 Issues found when validating {type.name.lower()} elements on model {model_id} against data warehouse"
         )
-    return results
+    return issues
 
 
-def _data_warehouse_validations_runner(
-    config: CLIContext,
-    model_id: Optional[int] = None,
-    show_all: bool = False,
-    additional_results: ModelValidationResults = ModelValidationResults(),
-    verbose_issues: bool = False,
-    timeout: Optional[int] = None,
-) -> bool:
+def _data_warehouse_validations_runner(config: CLIContext, model_id: Optional[int] = None) -> bool:
     """Helper which calls the individual data warehouse validations to run and prints collected issues"""
     # the only reason we do this is so that the model id is available in terminal output
     if model_id is None and config.current_model is not None:
         model_id = config.current_model.id
 
-    list_results: List[ModelValidationResults] = [additional_results]
-    list_results.append(
-        _run_dw_validations(
-            config=config, dw_validation_type=AsyncDWValidationType.data_source, model_id=model_id, timeout=timeout
-        )
-    )
-    list_results.append(
-        _run_dw_validations(
-            config=config, dw_validation_type=AsyncDWValidationType.dimension, model_id=model_id, timeout=timeout
-        )
-    )
-    list_results.append(
-        _run_dw_validations(
-            config=config, dw_validation_type=AsyncDWValidationType.identifier, model_id=model_id, timeout=timeout
-        )
-    )
-    list_results.append(
-        _run_dw_validations(
-            config=config, dw_validation_type=AsyncDWValidationType.measure, model_id=model_id, timeout=timeout
-        )
-    )
-    list_results.append(
-        _run_dw_validations(
-            config=config, dw_validation_type=AsyncDWValidationType.metric, model_id=model_id, timeout=timeout
-        )
-    )
-    merged_results = ModelValidationResults.merge(list_results)
-    _print_issues(merged_results, show_non_blocking=show_all, verbose=verbose_issues)
+    issues: List[str] = []
+    issues += _run_dw_validations(config=config, type=DWValidationType.DATA_SOURCE, model_id=model_id)
+    issues += _run_dw_validations(config=config, type=DWValidationType.DIMENSION, model_id=model_id)
+    issues += _run_dw_validations(config=config, type=DWValidationType.METRIC, model_id=model_id)
 
-    return not merged_results.has_blocking_issues
+    print(colored("\n".join(issues), "red"))
+    return len(issues) == 0
 
 
 @cli.command()
 @click.option("--model-id", type=int, required=False, help="Specific model id to run")
-@show_all_issues_option
-@verbose_issues_option
-@dw_timeout_option
 @pass_config
 @exception_handler
-def data_warehouse_validations(
-    config: CLIContext,
-    model_id: Optional[int] = None,
-    show_all: bool = True,
-    verbose_issues: bool = False,
-    timeout: Optional[int] = None,
-) -> None:
+def data_warehouse_validations(config: CLIContext, model_id: Optional[int] = None) -> None:
     """Run data warehouse validations for a model, defaults to current model"""
-    if not show_all:
-        print("(To see warnings and future-errors, run again with flag `--show-all`)")
-
-    _data_warehouse_validations_runner(
-        config=config, model_id=model_id, show_all=show_all, verbose_issues=verbose_issues, timeout=timeout
-    )
+    _data_warehouse_validations_runner(config=config, model_id=model_id)
 
 
 @cli.command()
 @config_validation_options
+@click.option(
+    "--skip-dw",
+    is_flag=True,
+    default=False,
+    help="If specified, skips the data warehouse validations",
+)
 @pass_config
 @exception_handler
-def validate_configs(
-    config: CLIContext,
-    config_dir: str,
-    skip_dw: bool = False,
-    show_all: bool = False,
-    verbose_issues: bool = False,
-    timeout: Optional[int] = None,
-) -> None:
+def validate_configs(config: CLIContext, config_dir: str, skip_dw: bool = False) -> None:
     """Validate yaml configs found in specified config directory"""
-    if not show_all:
-        print("(To see warnings and future-errors, run again with flag `--show-all`)")
-
-    # Lint configs before uploading them to the backend for parsing and semantic validations
-    lint_spinner = Halo(text="Checking for YAML format issues", spinner="dots")
-    lint_spinner.start()
-
-    lint_results = ConfigLinter().lint_dir(config_dir)
-    if not lint_results.has_blocking_issues:
-        lint_spinner.succeed(f"🎉 Successfully linted config YAML files ({lint_results.summary()})")
-    else:
-        lint_spinner.fail(f"Breaking issues found in config YAML files ({lint_results.summary()})")
-        _print_issues(lint_results, show_non_blocking=show_all, verbose=verbose_issues)
-        return
-
-    # Upload, parse, and semantically validate the model via the backend
-    commit_spinner = Halo(
-        text=f"Running parsing and semantic validations for configs in '{config_dir}'...", spinner="dots"
-    )
-    commit_spinner.start()
+    spinner = Halo(text=f"Running parsing and semantic validations for configs in '{config_dir}'...", spinner="dots")
+    spinner.start()
 
     # Currently if this fails, an exception is thrown, and the calling function handles it with a decorator
-    model, commit_results = config.mql.validate_configs(config_dir=config_dir)
-    combined_results = ModelValidationResults.merge([lint_results, commit_results])
-    if not commit_results.has_blocking_issues:
-        commit_spinner.succeed(
-            f"🦄 Successfully validated parsing and semantics of configs ({commit_results.summary()})"
-        )
-    else:
-        commit_spinner.fail(
-            f"Breaking issues found when validating parsing and semantics of configs ({commit_results.summary()})"
-        )
-        _print_issues(combined_results, show_non_blocking=show_all, verbose=verbose_issues)
-        return
+    model = config.mql.validate_configs(config_dir=config_dir)
+    spinner.succeed(
+        f"🦄 Successfully validated parsing and semantics of configs for commit ({model.commit}) in repo ({model.repository}), on branch ({model.branch})"
+    )
 
     if not skip_dw:
-        _data_warehouse_validations_runner(
-            config=config,
-            model_id=model.id,
-            show_all=show_all,
-            additional_results=combined_results,
-            verbose_issues=verbose_issues,
-            timeout=timeout,
-        )
+        _data_warehouse_validations_runner(config=config, model_id=model.id)
 
 
 @cli.command()
@@ -1054,6 +964,12 @@ def validate_configs(
 @click.option("--pin", type=bool, required=False, help="Whether to pin the model or not")
 @click.option("--force-primary", is_flag=True, default=None, help="Make this model current")
 @click.option("--dev-ui", is_flag=True, default=False, help="See the model in the Transform app")
+@click.option(
+    "--skip-dw",
+    is_flag=True,
+    default=False,
+    help="If specified, skips the data warehouse validations",
+)
 @pass_config
 @click.pass_context
 def commit_configs(
@@ -1064,55 +980,19 @@ def commit_configs(
     force_primary: Optional[bool] = None,
     dev_ui: bool = False,
     skip_dw: bool = False,
-    show_all: bool = False,
-    verbose_issues: bool = False,
-    timeout: Optional[int] = None,
 ) -> None:
     """Commit yaml configs found in specified config directory"""
-    if not show_all:
-        print("(To see warnings and future-errors, run again with flag `--show-all`)")
-
-    # Lint configs before uploading them to the backend for parsing and semantic validations
-    lint_spinner = Halo(text="Checking for YAML format issues", spinner="dots")
-    lint_spinner.start()
-
-    lint_results = ConfigLinter().lint_dir(config_dir)
-    if not lint_results.has_blocking_issues:
-        lint_spinner.succeed(f"🎉 Successfully linted config YAML files ({lint_results.summary()})")
-    else:
-        lint_spinner.fail(f"Breaking issues found in config YAML files ({lint_results.summary()})")
-        _print_issues(lint_results, show_non_blocking=show_all, verbose=verbose_issues)
-        return
-
-    # Upload, parse, and semantically validate the model via the backend
-    commit_spinner = Halo(
-        text=f"Running parsing and semantic validations for configs in '{config_dir}'...", spinner="dots"
-    )
-    commit_spinner.start()
+    spinner = Halo(text=f"Running parsing and semantic validations for configs in '{config_dir}'...", spinner="dots")
+    spinner.start()
 
     # Currently if this fails, an exception is thrown, and the calling function handles it with a decorator
-    model, commit_results = config.mql.commit_configs(config_dir=config_dir)
-    combined_results = ModelValidationResults.merge([lint_results, commit_results])
-    if not commit_results.has_blocking_issues:
-        commit_spinner.succeed(
-            f"🦄 Successfully validated parsing and semantics of configs ({commit_results.summary()})"
-        )
-    else:
-        commit_spinner.fail(
-            f"Breaking issues found when validating parsing and semantics of configs ({commit_results.summary()})"
-        )
-        _print_issues(combined_results, show_non_blocking=show_all, verbose=verbose_issues)
-        return
+    model = config.mql.commit_configs(config_dir=config_dir)
+    spinner.succeed(
+        f"🦄 Successfully validated parsing and semantics of configs for commit ({model.commit}) in repo ({model.repository}), on branch ({model.branch})"
+    )
 
     if not skip_dw:
-        success = _data_warehouse_validations_runner(
-            config=config,
-            model_id=model.id,
-            show_all=show_all,
-            additional_results=combined_results,
-            verbose_issues=verbose_issues,
-            timeout=timeout,
-        )
+        success = _data_warehouse_validations_runner(config=config, model_id=model.id)
         if not success:
             return
 
