@@ -1,4 +1,3 @@
-from datetime import datetime
 from enum import Enum
 import logging
 import functools
@@ -14,7 +13,6 @@ from typing import List, Dict, Optional, Tuple, Any
 from gql import Client, gql
 from gql.transport.requests import RequestsHTTPTransport
 
-from metricflow.model.validations.validator_helpers import ModelValidationResults
 from transform_tools.validate import (
     validate_configs as tt_validate_configs,
     commit_configs as tt_commit_configs,
@@ -30,8 +28,6 @@ from .models import (
     MqlQueryResultSource,
     MqlQueryStatus,
     MqlQueryStatusResp,
-    QueryJobStatusResp,
-    QueryJobType,
     QueryResult,
     CacheMode,
     Dimension,
@@ -53,19 +49,10 @@ logger = logging.getLogger(__name__)
 
 
 class DWValidationType(Enum):  # noqa: D
-    DATA_SOURCE = "dataSourceResults"
-    DIMENSION = "dimensionResults"
-    IDENTIFIER = "identifierResults"
-    MEASURE = "measureResults"
-    METRIC = "metricResults"
-
-
-class AsyncDWValidationType(Enum):  # noqa: D
-    data_source = "data_source"
-    dimension = "dimension"
-    identifier = "identifier"
-    measure = "measure"
-    metric = "metric"
+    ALL = "allIssues"
+    DATA_SOURCE = "dataSourceIssues"
+    DIMENSION = "dimensionIssues"
+    METRIC = "metricIssues"
 
 
 class BaseInterface:
@@ -146,7 +133,7 @@ class BackendInterface(BaseInterface):  # noqa: D
     ) -> None:
         super(BackendInterface, self).__init__(auth_header, rest_api_url, use_async)
 
-    def validate_configs(self, config_dir: str) -> Tuple[ModelKey, ModelValidationResults]:
+    def validate_configs(self, config_dir: str) -> ModelKey:
         """Finds and validates yaml configs in the provided directory"""
         repo, branch, commit = resolve_local_commit_info(config_dir)
         try:
@@ -157,10 +144,8 @@ class BackendInterface(BaseInterface):  # noqa: D
                 commit=commit,
                 config_dir=config_dir,
                 api_url=self.rest_api_url,
-                return_issues=True,
             )
-            json_resp = response.json()
-            return (ModelKey.from_snake_dict(json_resp["model"]), ModelValidationResults.parse_raw(json_resp["issues"]))
+            return ModelKey.from_snake_dict(response.json()["model"])
         except Exception as e:
             error_content = str(e).split(ERROR_RESPONSE_PREFIX)
             error_msg = str(e)
@@ -169,7 +154,7 @@ class BackendInterface(BaseInterface):  # noqa: D
                 error_msg = f"🙈 {error_response['error_type']}: {error_response['message']}"
             raise Exception(error_msg) from None
 
-    def commit_configs(self, config_dir: str, is_validation: bool = False) -> Tuple[ModelKey, ModelValidationResults]:
+    def commit_configs(self, config_dir: str, is_validation: bool = False) -> ModelKey:
         """Finds, validates, and commits yaml configs in the provided directory"""
         repo, branch, commit = resolve_local_commit_info(config_dir)
         try:
@@ -181,11 +166,8 @@ class BackendInterface(BaseInterface):  # noqa: D
                 config_dir=config_dir,
                 is_validation=is_validation,
                 api_url=self.rest_api_url,
-                return_issues=True,
             )
-            json_resp = response.json()
-            return (ModelKey.from_snake_dict(json_resp["model"]), ModelValidationResults.parse_raw(json_resp["issues"]))
-
+            return ModelKey.from_snake_dict(response.json()["model"])
         except Exception as e:
             error_content = str(e).split(ERROR_RESPONSE_PREFIX)
             error_msg = str(e)
@@ -847,11 +829,8 @@ class MQLInterface(BaseInterface):  # noqa: D
 
     def get_data_warehouse_validation_issues(
         self, dw_validation_type: DWValidationType, model_key: Optional[ModelKey] = None
-    ) -> ModelValidationResults:
-        """DEPRECATED: Use create_data_warehouse_validations_job + get_data_warehouse_validation_query instead
-
-        Get data warehouse validation issues associated with the dw_validation_type for the model
-        """
+    ) -> List[str]:
+        """Get data warehouse validation issues associated with the dw_validation_type for the model"""
         query = gql(
             f"""
             query ValidateModel{dw_validation_type.name}($modelKey: ModelKeyInput) {{
@@ -863,7 +842,7 @@ class MQLInterface(BaseInterface):  # noqa: D
         )
 
         # TODO: If this starts timing out we should move to a createMqlQuery approach
-        json_validation_result: str = self.execute(
+        return self.execute(
             query,
             variable_values={
                 "modelKey": {
@@ -876,31 +855,6 @@ class MQLInterface(BaseInterface):  # noqa: D
                 else None
             },
         )["validations"][dw_validation_type.value]
-        return ModelValidationResults.parse_raw(json_validation_result)
-
-    def create_data_warehouse_validations_job(
-        self, dw_validation_type: AsyncDWValidationType, model_id: Optional[int]
-    ) -> str:
-        """Implements createDataWarehouseValidationsQuery mutation in MQL/GQL"""
-        query = gql(
-            """
-            mutation CreateDataWarehouseValidationsQuery(
-                $modelId: Int,
-                $validationType: DataWarehouseValidationRequestType!
-            ) {
-                createDataWarehouseValidationsQuery(
-                    modelId: $modelId,
-                    validationType: $validationType
-                ) {
-                    id
-                }
-            }
-            """
-        )
-
-        params = {"modelId": model_id, "validationType": dw_validation_type.name}
-
-        return self.execute(query, variable_values=params)["createDataWarehouseValidationsQuery"]["id"]
 
     def create_query(  # noqa: D
         self,
@@ -1134,36 +1088,6 @@ class MQLInterface(BaseInterface):  # noqa: D
             warnings=q["warnings"],
         )
 
-    def get_query_job_status(self, query_id: str) -> QueryJobStatusResp:
-        """Retrieves query status given a query_id"""
-        query = gql(
-            """
-            query GetQueryJobResultsStatus($queryId: ID!) {
-                queryJob(id: $queryId) {
-                    id
-                    status
-                    startTime
-                    endTime
-                    queryRuntime
-                    queryType
-                    error
-                }
-            }
-            """
-        )
-
-        q = self.execute(query, variable_values={"queryId": query_id})["queryJob"]
-
-        return QueryJobStatusResp(
-            query_id=query_id,
-            status=MqlQueryStatus[q["status"]],
-            error=q["error"] if q["error"] else None,
-            startTime=datetime.fromisoformat(q["startTime"]) if q["startTime"] else None,
-            endTime=datetime.fromisoformat(q["endTime"]) if q["endTime"] else None,
-            queryRuntime=q["queryRuntime"] if q["queryRuntime"] else None,
-            queryType=QueryJobType[q["queryType"]],
-        )
-
     def get_queries(self, active_only: bool, limit: Optional[int]) -> List[Query]:
         """Retrieves query status given a query_id"""
         query = gql(
@@ -1229,23 +1153,6 @@ class MQLInterface(BaseInterface):  # noqa: D
             cursor=tabular["nextCursor"],
         )
 
-    def get_data_warehouse_query_as_model_validation_results(self, query_id: str) -> ModelValidationResults:
-        """Retrieves a ModelValidationResults of a model validation query's results"""
-        query = gql(
-            """
-            query GetDataWarehouseValidationQuery($queryId: ID!) {
-                queryJob(id: $queryId) {
-                    dataWarehouseValidationsResult
-                }
-            }
-            """
-        )
-
-        dw_validation_result = self.execute(query, variable_values={"queryId": query_id})["queryJob"][
-            "dataWarehouseValidationsResult"
-        ]
-        return ModelValidationResults.parse_raw(dw_validation_result)
-
     def poll_for_query_completion(self, query_id: str, timeout: Optional[int] = None) -> MqlQueryStatusResp:
         """Poll for query completion, displaying some progress indication."""
         timeout = timeout if timeout is not None else DEFAULT_QUERY_TIMEOUT
@@ -1268,28 +1175,6 @@ class MQLInterface(BaseInterface):  # noqa: D
             f"Timeout reached waiting for query {query_id} to complete after {timeout} seconds. Please see --timeout option to override.",
         )
 
-    def poll_for_job_completion(self, query_id: str, timeout: Optional[int] = None) -> QueryJobStatusResp:
-        """Poll for query job completion, displaying some progress indication."""
-        timeout = timeout if timeout is not None else DEFAULT_QUERY_TIMEOUT
-        start = time.time()
-
-        # Poll until the query is complete or we hit the timeout (timeout of 0 indicate no timeout)
-        poll_interval = 1.0
-        while timeout == 0 or time.time() < start + timeout:
-            query_result = self.get_query_job_status(query_id)
-            if query_result.is_complete:
-                return query_result
-            time.sleep(poll_interval)
-
-            # poll interval starts very low and gets longer until we hit a maximum of 10s
-            # allows us to resolve fast queries quickly without hammering mql for long queries
-            poll_interval = min(10.0, poll_interval * 1.5)
-
-        raise QueryRuntimeException(
-            query_id,
-            f"Timeout reached waiting for query job {query_id} to complete after {timeout} seconds. Please see --timeout option to override.",
-        )
-
     def get_materialization_result(self, query_id: str, timeout: Optional[int] = None) -> Tuple[str, str]:
         """Retrieves materialized table resulting from successful materialization query"""
         resp = self.poll_for_query_completion(query_id, timeout=timeout)
@@ -1320,21 +1205,6 @@ class MQLInterface(BaseInterface):  # noqa: D
 
         return df
 
-    def get_data_warehouse_validation_query(
-        self, query_id: str, timeout: Optional[int] = None
-    ) -> ModelValidationResults:
-        """Retrieves data warehouse validation results
-
-        Includes logic for:
-        1. Polling for completion
-        2. Converting JSON to a ModelValidationResults
-        """
-        resp = self.poll_for_job_completion(query_id, timeout=timeout)
-        if not resp.is_successful:
-            raise QueryRuntimeException.from_query_response(resp)
-
-        return self.get_data_warehouse_query_as_model_validation_results(query_id)
-
     def invalidate_all_caches(self) -> bool:
         """Invalidates all caches in the server."""
         query = gql(
