@@ -236,6 +236,14 @@ class TimeGranularity(Enum):
     YEAR = "year"
 
 
+class PrintStyle(Enum):
+    """For use in choosing which style/format to print query results"""
+
+    PLAIN = "plain"
+    STANDARD = "standard"
+    PRETTY = "pretty"
+
+
 class MqlQueryStatus(Enum):
     """The status of queries submitted for execution in the query manager."""
 
@@ -261,6 +269,8 @@ class MqlQueryResultSource(Enum):
     METRICFLOW = "METRICFLOW"
     NOT_APPLICABLE = "NOT_APPLICABLE"
     NOT_SPECIFIED = "NOT_SPECIFIED"
+    DIMENSION_VALUES_CACHE = "DIMENSION_VALUES_CACHE"
+    MATERIALIZED_QUERY_CACHE = "MATERIALIZED_QUERY_CACHE"
 
 
 @dataclass(frozen=True)
@@ -282,14 +292,7 @@ class MqlQueryStatusResp:  # noqa: D
     result: Optional[List[MqlQueryResultSeries]]
     result_source: Optional[MqlQueryResultSource]
     result_primary_time_granularity: Optional[TimeGranularity]
-
-    def __post_init__(self) -> None:  # noqa: D
-        if not self.is_successful:
-            assert self.chart_value_min is None
-            assert self.chart_value_min is None
-            assert self.result is None
-            assert self.result_source is None
-            assert self.result_primary_time_granularity is None
+    warnings: List[str]
 
     @property
     def is_complete(self) -> bool:
