@@ -57,6 +57,7 @@ class MQLClient:
         result_format: Optional[str] = None,
         start_time: Optional[str] = None,
         end_time: Optional[str] = None,
+        trim: Optional[bool] = None,
     ) -> MqlQueryStatusResp:
         """Builds a query in MQL and returns a MqlQueryStatusResp detailing the results."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
@@ -76,6 +77,7 @@ class MQLClient:
             result_format,
             start_time,
             end_time,
+            trim,
         )
         return self.context.mql_client.get_query_status(query_id)
 
@@ -181,6 +183,7 @@ class MQLClient:
             chart_value_min=resp.chart_value_min,
             result_source=resp.result_source,
             result_primary_time_granularity=resp.result_primary_time_granularity,
+            warnings=resp.warnings,
         )
 
     def list_queries(self, active_only: bool, limit: Optional[int] = None) -> List[Query]:
@@ -381,3 +384,15 @@ class MQLClient:
         model_key = self.get_model_key(model_key_id) if model_key_id else None
         issues = self.context.mql_client.get_data_warehouse_validation_issues(type, model_key)
         return issues
+
+    def get_query_status(self, query_id: str) -> MqlQueryStatusResp:
+        """Returns a query response object."""
+        return self.context.mql_client.get_query_status(query_id)
+
+    def invalidate_all_caches(self) -> bool:
+        """Invalidates all caches."""
+        return self.context.mql_client.invalidate_all_caches()
+
+    def invalidate_cache_for_metric(self, metric_name: str) -> bool:
+        """Invalidates caches related to the given metric."""
+        return self.context.mql_client.invalidate_cache_for_metric(metric_name)
